==> retext_3.1.0.orig.tar.gz: locale/retext_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0" language="fr" sourcelanguage="">
<context>
    <name>LogPassDialog</name>
    <message>
        <location filename="retext.py" line="208"/>
        <source>Enter your Google account data</source>
        <translation>Entrez vos données du compte Google</translation>
    </message>
    <message>
        <location filename="retext.py" line="217"/>
        <source>Username</source>
        <translation>Utilisateur</translation>
    </message>
    <message>
        <location filename="retext.py" line="218"/>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
</context>
<context>
    <name>ReTextWindow</name>
    <message>
        <location filename="retext.py" line="1421"/>
        <source>New document</source>
        <translation>Nouveau document</translation>
    </message>
    <message>
        <location filename="retext.py" line="287"/>
        <source>File toolbar</source>
        <translation>Barre d&apos;outil Fichier</translation>
    </message>
    <message>
        <location filename="retext.py" line="289"/>
        <source>Edit toolbar</source>
        <translation>Barre d&apos;outil Édition</translation>
    </message>
    <message>
        <location filename="retext.py" line="291"/>
        <source>Search toolbar</source>
        <translation>Barre d&apos;outil Rechercher</translation>
    </message>
    <message>
        <location filename="retext.py" line="293"/>
        <source>New</source>
        <translation>Nouveau</translation>
    </message>
    <message>
        <location filename="retext.py" line="295"/>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <location filename="retext.py" line="297"/>
        <source>Save</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <location filename="retext.py" line="300"/>
        <source>Save as</source>
        <translation>Enregistrer Sous</translation>
    </message>
    <message>
        <location filename="retext.py" line="302"/>
        <source>Print</source>
        <translation>Imprimer</translation>
    </message>
    <message>
        <location filename="retext.py" line="304"/>
        <source>Print preview</source>
        <translation>Aperçu d&apos;impression</translation>
    </message>
    <message>
        <location filename="retext.py" line="306"/>
        <source>View HTML code</source>
        <translation>Voir code HTML</translation>
    </message>
    <message>
        <location filename="retext.py" line="307"/>
        <source>Change default font</source>
        <translation>Changer police par défaut</translation>
    </message>
    <message>
        <location filename="retext.py" line="308"/>
        <source>Find text</source>
        <translation>Chercher text</translation>
    </message>
    <message>
        <location filename="retext.py" line="312"/>
        <source>Preview</source>
        <translation>Aperçu</translation>
    </message>
    <message>
        <location filename="retext.py" line="321"/>
        <source>Live preview</source>
        <translation>Aperçu live</translation>
    </message>
    <message>
        <location filename="retext.py" line="323"/>
        <source>Fullscreen mode</source>
        <translation>Mode plein écran</translation>
    </message>
    <message>
        <location filename="retext.py" line="329"/>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="retext.py" line="332"/>
        <source>Undo</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="retext.py" line="334"/>
        <source>Redo</source>
        <translation>Rétablir</translation>
    </message>
    <message>
        <location filename="retext.py" line="336"/>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <location filename="retext.py" line="338"/>
        <source>Cut</source>
        <translation>Couper</translation>
    </message>
    <message>
        <location filename="retext.py" line="340"/>
        <source>Paste</source>
        <translation>Coller</translation>
    </message>
    <message>
        <location filename="retext.py" line="349"/>
        <source>Enable</source>
        <translation>Activer</translation>
    </message>
    <message>
        <location filename="retext.py" line="350"/>
        <source>Set locale</source>
        <translation>choisir langue</translation>
    </message>
    <message>
        <location filename="retext.py" line="351"/>
        <source>Plain text</source>
        <translation>Format Text</translation>
    </message>
    <message>
        <location filename="retext.py" line="438"/>
        <source>Open recent</source>
        <translation>Ouvrir récent</translation>
    </message>
    <message>
        <location filename="retext.py" line="360"/>
        <source>Generate webpages</source>
        <translation>Générer pages web</translation>
    </message>
    <message>
        <location filename="retext.py" line="361"/>
        <source>Show</source>
        <translation>Montrer</translation>
    </message>
    <message>
        <location filename="retext.py" line="362"/>
        <source>Next</source>
        <translation>Suivant</translation>
    </message>
    <message>
        <location filename="retext.py" line="363"/>
        <source>Previous</source>
        <translation>Précédent</translation>
    </message>
    <message>
        <location filename="retext.py" line="365"/>
        <source>Get help online</source>
        <translation>Aide en ligne</translation>
    </message>
    <message>
        <location filename="retext.py" line="373"/>
        <source>About Qt</source>
        <translation>À propos de Qt</translation>
    </message>
    <message>
        <location filename="retext.py" line="399"/>
        <source>Save to Google Docs</source>
        <translation>Enregistrer sur Google Docs</translation>
    </message>
    <message>
        <location filename="retext.py" line="406"/>
        <source>Tags</source>
        <translation>Tags</translation>
    </message>
    <message>
        <location filename="retext.py" line="410"/>
        <source>Symbols</source>
        <translation>Symboles</translation>
    </message>
    <message>
        <location filename="retext.py" line="433"/>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location filename="retext.py" line="434"/>
        <source>Edit</source>
        <translation>Édition</translation>
    </message>
    <message>
        <location filename="retext.py" line="435"/>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <location filename="retext.py" line="441"/>
        <source>Directory</source>
        <translation>Répertoire</translation>
    </message>
    <message>
        <location filename="retext.py" line="449"/>
        <source>Export</source>
        <translation>Exporter</translation>
    </message>
    <message>
        <location filename="retext.py" line="474"/>
        <source>Spell check</source>
        <translation>Vérificateur</translation>
    </message>
    <message>
        <location filename="retext.py" line="482"/>
        <source>Default editing mode</source>
        <translation>Mode d&apos;édition par défaut</translation>
    </message>
    <message>
        <location filename="retext.py" line="523"/>
        <source>Search</source>
        <translation>Chercher</translation>
    </message>
    <message>
        <location filename="retext.py" line="526"/>
        <source>Case sensitively</source>
        <translation>Respect de la casse</translation>
    </message>
    <message>
        <location filename="retext.py" line="563"/>
        <source>You have neither Markdown nor Docutils modules installed!</source>
        <translation>Vous n&apos;avez pas Markdown, ni Docutils d&apos;installé !</translation>
    </message>
    <message>
        <location filename="retext.py" line="819"/>
        <source>Enter locale name (example: en_US)</source>
        <translation>Entrez le préfix pour la lagnue (exemple: fr_FR)</translation>
    </message>
    <message>
        <location filename="retext.py" line="916"/>
        <source>Please, save the file somewhere.</source>
        <translation>SVP, enregistrer le fichier quelque part.</translation>
    </message>
    <message>
        <location filename="retext.py" line="903"/>
        <source>Webpages saved in &lt;code&gt;html&lt;/code&gt; directory.</source>
        <translation>Pages enregistrés dans le répertoire &lt;code&gt;html&lt;/code&gt;.</translation>
    </message>
    <message>
        <location filename="retext.py" line="1032"/>
        <source>Select one or several files to open</source>
        <translation>choisir un ou plusieurs fichiers pour ouvrir</translation>
    </message>
    <message>
        <location filename="retext.py" line="1032"/>
        <source>Supported files</source>
        <translation>Formats supportés</translation>
    </message>
    <message>
        <location filename="retext.py" line="1032"/>
        <source>All files (*)</source>
        <translation>Tous fichiers (*)</translation>
    </message>
    <message>
        <location filename="retext.py" line="1091"/>
        <source>Plain text (*.txt)</source>
        <translation>Fichier text (*.txt)</translation>
    </message>
    <message>
        <location filename="retext.py" line="1094"/>
        <source>ReStructuredText files</source>
        <translation>Fichiers ReStructuredText</translation>
    </message>
    <message>
        <location filename="retext.py" line="1097"/>
        <source>Markdown files</source>
        <translation>Fichiers Markdown</translation>
    </message>
    <message>
        <location filename="retext.py" line="1174"/>
        <source>Save file</source>
        <translation>Enregistrer fichier</translation>
    </message>
    <message>
        <location filename="retext.py" line="1165"/>
        <source>Export document to ODT</source>
        <translation>Exporter document vers ODT</translation>
    </message>
    <message>
        <location filename="retext.py" line="1165"/>
        <source>OpenDocument text files (*.odt)</source>
        <translation>Fichier text OpenDocument (*.odt)</translation>
    </message>
    <message>
        <location filename="retext.py" line="1174"/>
        <source>HTML files (*.html *.htm)</source>
        <translation>Fichier HTML (*.html, *.htm)</translation>
    </message>
    <message>
        <location filename="retext.py" line="1197"/>
        <source>Export document to PDF</source>
        <translation>Exporter document vers PDF</translation>
    </message>
    <message>
        <location filename="retext.py" line="1197"/>
        <source>PDF files (*.pdf)</source>
        <translation>Fichiers PDF (*.pdf)</translation>
    </message>
    <message>
        <location filename="retext.py" line="1212"/>
        <source>Print document</source>
        <translation>Imprimer document</translation>
    </message>
    <message>
        <location filename="retext.py" line="1231"/>
        <source>Export document</source>
        <translation>Exporter document</translation>
    </message>
    <message>
        <location filename="retext.py" line="1316"/>
        <source>Incorrect user name or password!</source>
        <translation>Utilisateur ou mot de passe incorrect !</translation>
    </message>
    <message>
        <location filename="retext.py" line="1395"/>
        <source>The document has been modified.
Do you want to save your changes?</source>
        <translation>Le document a changé.
Voulez vous enregistrer vos changements ?</translation>
    </message>
    <message>
        <location filename="retext.py" line="1428"/>
        <source>HTML code</source>
        <translation>Code HTML</translation>
    </message>
    <message>
        <location filename="retext.py" line="1437"/>
        <source>Simple but powerful editor for Markdown and ReStructuredText</source>
        <translation>Éditeur de Markdown et ReStructuredText simple mais puissant</translation>
    </message>
    <message>
        <location filename="retext.py" line="1437"/>
        <source>Author: Dmitry Shachnev, 2011</source>
        <translation>Auteur :Dmity Schachnev, 2011</translation>
    </message>
    <message>
        <location filename="retext.py" line="1437"/>
        <source>Website</source>
        <translation>Site Web</translation>
    </message>
    <message>
        <location filename="retext.py" line="1437"/>
        <source>Markdown syntax</source>
        <translation>Syntaxe Markdown</translation>
    </message>
    <message>
        <location filename="retext.py" line="1437"/>
        <source>ReST syntax</source>
        <translation>Syntaxe Rest</translation>
    </message>
    <message>
        <location filename="retext.py" line="1488"/>
        <source>Could not parse file contents, check if you have the necessary module installed!</source>
        <translation>Ne peut analyser le contenu du fichier, vérifier si les modules sont bien installés</translation>
    </message>
    <message>
        <location filename="retext.py" line="905"/>
        <source>Show directory</source>
        <translation>Montrer répertoire</translation>
    </message>
    <message>
        <location filename="retext.py" line="910"/>
        <source>Webpages generator is not installed!</source>
        <translation>Générateur Webpages non installé !</translation>
    </message>
    <message>
        <location filename="retext.py" line="1112"/>
        <source>Cannot save to file because it is read-only!</source>
        <translation>Ne peut enregistrer le fichier car en lecture seule !</translation>
    </message>
    <message>
        <location filename="retext.py" line="1319"/>
        <source>Authentification failed, please check your internet connection!</source>
        <translation>Authentification echouée, svp vérifier votre connection internet !</translation>
    </message>
    <message>
        <location filename="retext.py" line="394"/>
        <source>Bold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="retext.py" line="395"/>
        <source>Italic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="retext.py" line="396"/>
        <source>Underline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="retext.py" line="485"/>
        <source>Formatting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="retext.py" line="370"/>
        <source>About %s</source>
        <translation>À propos de %s</translation>
    </message>
    <message>
        <location filename="retext.py" line="353"/>
        <source>Use WebKit renderer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="retext.py" line="1255"/>
        <source>Failed to execute the command:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> retext_3.1.4.orig.tar.gz: locale/retext_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0" language="fr" sourcelanguage="">
<context>
    <name>LogPassDialog</name>
    <message>
        <location filename="retext.py" line="208"/>
        <source>Enter your Google account data</source>
        <translation>Saisissez vos vos informations de compte Google</translation>
    </message>
    <message>
        <location filename="retext.py" line="217"/>
        <source>Username</source>
        <translation>Nom d&apos;utilisateur</translation>
    </message>
    <message>
        <location filename="retext.py" line="218"/>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
</context>
<context>
    <name>ReTextWindow</name>
    <message>
        <location filename="retext.py" line="287"/>
        <source>File toolbar</source>
        <translation>Barre d&apos;outil Fichier</translation>
    </message>
    <message>
        <location filename="retext.py" line="289"/>
        <source>Edit toolbar</source>
        <translation>Barre d&apos;outil Édition</translation>
    </message>
    <message>
        <location filename="retext.py" line="291"/>
        <source>Search toolbar</source>
        <translation>Barre d&apos;outil de recherche</translation>
    </message>
    <message>
        <location filename="retext.py" line="293"/>
        <source>New</source>
        <translation>Nouveau</translation>
    </message>
    <message>
        <location filename="retext.py" line="295"/>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <location filename="retext.py" line="297"/>
        <source>Save</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <location filename="retext.py" line="300"/>
        <source>Save as</source>
        <translation>Enregistrer Sous</translation>
    </message>
    <message>
        <location filename="retext.py" line="302"/>
        <source>Print</source>
        <translation>Imprimer</translation>
    </message>
    <message>
        <location filename="retext.py" line="304"/>
        <source>Print preview</source>
        <translation>Aperçu avant impression</translation>
    </message>
    <message>
        <location filename="retext.py" line="306"/>
        <source>View HTML code</source>
        <translation>Voir le code HTML</translation>
    </message>
    <message>
        <location filename="retext.py" line="307"/>
        <source>Change default font</source>
        <translation>Changer la police par défaut</translation>
    </message>
    <message>
        <location filename="retext.py" line="308"/>
        <source>Find text</source>
        <translation>Rechercher un texte</translation>
    </message>
    <message>
        <location filename="retext.py" line="312"/>
        <source>Preview</source>
        <translation>Aperçu</translation>
    </message>
    <message>
        <location filename="retext.py" line="321"/>
        <source>Live preview</source>
        <translation>Aperçu direct</translation>
    </message>
    <message>
        <location filename="retext.py" line="323"/>
        <source>Fullscreen mode</source>
        <translation>Mode plein écran</translation>
    </message>
    <message>
        <location filename="retext.py" line="329"/>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="retext.py" line="332"/>
        <source>Undo</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="retext.py" line="334"/>
        <source>Redo</source>
        <translation>Rétablir</translation>
    </message>
    <message>
        <location filename="retext.py" line="336"/>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <location filename="retext.py" line="338"/>
        <source>Cut</source>
        <translation>Couper</translation>
    </message>
    <message>
        <location filename="retext.py" line="340"/>
        <source>Paste</source>
        <translation>Coller</translation>
    </message>
    <message>
        <location filename="retext.py" line="349"/>
        <source>Enable</source>
        <translation>Activer</translation>
    </message>
    <message>
        <location filename="retext.py" line="350"/>
        <source>Set locale</source>
        <translation>Choisir la langue</translation>
    </message>
    <message>
        <location filename="retext.py" line="351"/>
        <source>Plain text</source>
        <translation>Texte brut</translation>
    </message>
    <message>
        <location filename="retext.py" line="353"/>
        <source>Use WebKit renderer</source>
        <translation>Utiliser le rendu de WebKit</translation>
    </message>
    <message>
        <location filename="retext.py" line="360"/>
        <source>Generate webpages</source>
        <translation>Générer les pages web</translation>
    </message>
    <message>
        <location filename="retext.py" line="361"/>
        <source>Show</source>
        <translation>Afficher</translation>
    </message>
    <message>
        <location filename="retext.py" line="362"/>
        <source>Next</source>
        <translation>Suivant</translation>
    </message>
    <message>
        <location filename="retext.py" line="363"/>
        <source>Previous</source>
        <translation>Précédent</translation>
    </message>
    <message>
        <location filename="retext.py" line="365"/>
        <source>Get help online</source>
        <translation>Assistance en ligne</translation>
    </message>
    <message>
        <location filename="retext.py" line="370"/>
        <source>About %s</source>
        <translation>À propos de %s</translation>
    </message>
    <message>
        <location filename="retext.py" line="373"/>
        <source>About Qt</source>
        <translation>À propos de Qt</translation>
    </message>
    <message>
        <location filename="retext.py" line="394"/>
        <source>Bold</source>
        <translation>Gras</translation>
    </message>
    <message>
        <location filename="retext.py" line="395"/>
        <source>Italic</source>
        <translation>Italique</translation>
    </message>
    <message>
        <location filename="retext.py" line="396"/>
        <source>Underline</source>
        <translation>Souligné</translation>
    </message>
    <message>
        <location filename="retext.py" line="399"/>
        <source>Save to Google Docs</source>
        <translation>Enregistrer sur Google Docs</translation>
    </message>
    <message>
        <location filename="retext.py" line="406"/>
        <source>Tags</source>
        <translation>Mots-clefs</translation>
    </message>
    <message>
        <location filename="retext.py" line="410"/>
        <source>Symbols</source>
        <translation>Symboles</translation>
    </message>
    <message>
        <location filename="retext.py" line="433"/>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location filename="retext.py" line="434"/>
        <source>Edit</source>
        <translation>Édition</translation>
    </message>
    <message>
        <location filename="retext.py" line="435"/>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <location filename="retext.py" line="438"/>
        <source>Open recent</source>
        <translation>Ouvrir les fichiers récents</translation>
    </message>
    <message>
        <location filename="retext.py" line="441"/>
        <source>Directory</source>
        <translation>Répertoire</translation>
    </message>
    <message>
        <location filename="retext.py" line="449"/>
        <source>Export</source>
        <translation>Exporter</translation>
    </message>
    <message>
        <location filename="retext.py" line="474"/>
        <source>Spell check</source>
        <translation>Vérifier l&apos;orthographe</translation>
    </message>
    <message>
        <location filename="retext.py" line="482"/>
        <source>Default editing mode</source>
        <translation>Mode d&apos;édition par défaut</translation>
    </message>
    <message>
        <location filename="retext.py" line="485"/>
        <source>Formatting</source>
        <translation>Formatage</translation>
    </message>
    <message>
        <location filename="retext.py" line="523"/>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <location filename="retext.py" line="526"/>
        <source>Case sensitively</source>
        <translation>Sensible à la casse</translation>
    </message>
    <message>
        <location filename="retext.py" line="1431"/>
        <source>New document</source>
        <translation>Nouveau document</translation>
    </message>
    <message>
        <location filename="retext.py" line="563"/>
        <source>You have neither Markdown nor Docutils modules installed!</source>
        <translation>Vous n&apos;avez ni Markdown, ni Docutils d&apos;installé !</translation>
    </message>
    <message>
        <location filename="retext.py" line="819"/>
        <source>Enter locale name (example: en_US)</source>
        <translation>Saisir le code de la langue (par exemple : fr_FR)</translation>
    </message>
    <message>
        <location filename="retext.py" line="926"/>
        <source>Please, save the file somewhere.</source>
        <translation>Veuillez enregistrer le fichier quelque part.</translation>
    </message>
    <message>
        <location filename="retext.py" line="913"/>
        <source>Webpages saved in &lt;code&gt;html&lt;/code&gt; directory.</source>
        <translation>Pages web enregistrées dans le répertoire &lt;code&gt;html&lt;/code&gt;.</translation>
    </message>
    <message>
        <location filename="retext.py" line="915"/>
        <source>Show directory</source>
        <translation>Afficher le répertoire</translation>
    </message>
    <message>
        <location filename="retext.py" line="920"/>
        <source>Webpages generator is not installed!</source>
        <translation>Le générateur de pages web n&apos;est pas installé !</translation>
    </message>
    <message>
        <location filename="retext.py" line="1042"/>
        <source>Select one or several files to open</source>
        <translation>Choisir un ou plusieurs fichiers à ouvrir</translation>
    </message>
    <message>
        <location filename="retext.py" line="1042"/>
        <source>Supported files</source>
        <translation>Formats acceptés</translation>
    </message>
    <message>
        <location filename="retext.py" line="1042"/>
        <source>All files (*)</source>
        <translation>Tous les fichiers (*)</translation>
    </message>
    <message>
        <location filename="retext.py" line="1101"/>
        <source>Plain text (*.txt)</source>
        <translation>Fichier text (*.txt)</translation>
    </message>
    <message>
        <location filename="retext.py" line="1104"/>
        <source>ReStructuredText files</source>
        <translation>Fichiers ReStructuredText</translation>
    </message>
    <message>
        <location filename="retext.py" line="1107"/>
        <source>Markdown files</source>
        <translation>Fichiers Markdown</translation>
    </message>
    <message>
        <location filename="retext.py" line="1186"/>
        <source>Save file</source>
        <translation>Enregistrer le fichier</translation>
    </message>
    <message>
        <location filename="retext.py" line="1124"/>
        <source>Cannot save to file because it is read-only!</source>
        <translation>Impossible d&apos;enregistrer le fichier car il est en lecture seule !</translation>
    </message>
    <message>
        <location filename="retext.py" line="1177"/>
        <source>Export document to ODT</source>
        <translation>Exporter le document au format ODT</translation>
    </message>
    <message>
        <location filename="retext.py" line="1177"/>
        <source>OpenDocument text files (*.odt)</source>
        <translation>Fichiers OpenDocument texte (*.odt)</translation>
    </message>
    <message>
        <location filename="retext.py" line="1186"/>
        <source>HTML files (*.html *.htm)</source>
        <translation>Fichier HTML (*.html, *.htm)</translation>
    </message>
    <message>
        <location filename="retext.py" line="1208"/>
        <source>Export document to PDF</source>
        <translation>Exporter le document au format PDF</translation>
    </message>
    <message>
        <location filename="retext.py" line="1208"/>
        <source>PDF files (*.pdf)</source>
        <translation>Fichiers PDF (*.pdf)</translation>
    </message>
    <message>
        <location filename="retext.py" line="1223"/>
        <source>Print document</source>
        <translation>Imprimer le document</translation>
    </message>
    <message>
        <location filename="retext.py" line="1242"/>
        <source>Export document</source>
        <translation>Exporter le document</translation>
    </message>
    <message>
        <location filename="retext.py" line="1265"/>
        <source>Failed to execute the command:</source>
        <translation>Échec lors de l&apos;exécution de la commande :</translation>
    </message>
    <message>
        <location filename="retext.py" line="1326"/>
        <source>Incorrect user name or password!</source>
        <translation>Nom d&apos;utilisateur ou mot de passe incorrect !</translation>
    </message>
    <message>
        <location filename="retext.py" line="1329"/>
        <source>Authentification failed, please check your internet connection!</source>
        <translation>Authentification échouée, veuillez vérifier votre connexion internet !</translation>
    </message>
    <message>
        <location filename="retext.py" line="1405"/>
        <source>The document has been modified.
Do you want to save your changes?</source>
        <translation>Le document a modifié.
Voulez vous enregistrer vos changements ?</translation>
    </message>
    <message>
        <location filename="retext.py" line="1438"/>
        <source>HTML code</source>
        <translation>Code HTML</translation>
    </message>
    <message>
        <location filename="retext.py" line="1447"/>
        <source>Simple but powerful editor for Markdown and ReStructuredText</source>
        <translation>Éditeur simple mais puissant pour Markdown et ReStructuredText</translation>
    </message>
    <message>
        <location filename="retext.py" line="1447"/>
        <source>Author: Dmitry Shachnev, 2011</source>
        <translation>Auteur: Dmitry Shachnev, 2011</translation>
    </message>
    <message>
        <location filename="retext.py" line="1447"/>
        <source>Website</source>
        <translation>Site Web</translation>
    </message>
    <message>
        <location filename="retext.py" line="1447"/>
        <source>Markdown syntax</source>
        <translation>Syntaxe Markdown</translation>
    </message>
    <message>
        <location filename="retext.py" line="1447"/>
        <source>ReST syntax</source>
        <translation>Syntaxe ReST</translation>
    </message>
    <message>
        <location filename="retext.py" line="1498"/>
        <source>Could not parse file contents, check if you have the necessary module installed!</source>
        <translation>Impossible d&apos;analyser le contenu du fichier, vérifier si les modules sont bien installés</translation>
    </message>
</context>
</TS>
